@@ -324,6 +324,24 @@ class QywxClient(_QywxBase):
         }
         return self.getRequest("https://qyapi.weixin.qq.com/cgi-bin/user/getuserinfo", _params)
 
+    def OauthGetAuthInfor(self, code: str):
+        """
+        从oauth认证传递的code获取用户的授权身份
+        """
+        _params = {
+            "code": code
+        }
+        return self.getRequest("https://qyapi.weixin.qq.com/cgi-bin/auth/getuserinfo", _params)
+    
+    def OauthGetAuthUserDetailInfor(self, user_ticket: str):
+        """
+        用从oauth获取的授权码user_ticket置换用户详细信息
+        """
+        _params = {
+            "user_ticket": user_ticket
+        }
+        return self.postRequest("https://qyapi.weixin.qq.com/cgi-bin/auth/getuserdetail", _params)
+
     def CommunicationBook(self):
         """
         获取完整的通信录信息
